@@ -15,8 +15,8 @@ from coldtype.text.reader import normalize_font_prefix, Font, Style
 from coldtype.pens.datpen import DATPen, DATPens
 from coldtype.pens.dattext import DATText
 from coldtype.time.audio import Wavfile, sf
-from coldtype.geometry import Rect, Point
-from coldtype.color import normalize_color, hsl, bw
+from drafting.geometry import Rect, Point
+from drafting.color import normalize_color, hsl, bw
 
 from coldtype.renderable.renderable import renderable, drawbot_script, Action, RenderPass, Overlay
 
@@ -32,7 +32,7 @@ class animation(renderable, Timeable):
     """
     Base class for any frame-wise animation animatable by Coldtype
     """
-    def __init__(self, rect=(1080, 1080), duration=10, storyboard=[0], timeline:Timeline=None, audio=None, **kwargs):
+    def __init__(self, rect=(1080, 1080), duration=10, storyboard=[0], timeline:Timeline=None, audio=None, show_frame=True, **kwargs):
         super().__init__(**kwargs)
         self.rect = Rect(rect)
         self.r = self.rect
@@ -43,6 +43,7 @@ class animation(renderable, Timeable):
             self.wavfile = None
         self.start = 0
         self.end = duration
+        self.show_frame = show_frame
         
         self.storyboard = storyboard
         if timeline:
@@ -118,7 +119,7 @@ class animation(renderable, Timeable):
     def runpost(self, result, render_pass, renderer_state):
         res = super().runpost(result, render_pass, renderer_state)
         if Overlay.Info in renderer_state.overlays:
-            t = self.rect.take(50, "mxy")
+            t = self.rect.take(50, "mny")
             frame:Frame = render_pass.args[0]
             wave = DATPen()
             if self.audio and sf:
@@ -130,14 +131,17 @@ class animation(renderable, Timeable):
             return DATPens([
                 wave,
                 res,
-                DATPen().rect(t).f(bw(0, 0.75)),
-                DATText(f"{frame.i} / {self.duration}", Style("Times", 42, load_font=0, fill=bw(1)), t.inset(10))
+                DATPen().rect(t).f(bw(0, 0.75)) if self.show_frame else None,
+                DATText(f"{frame.i} / {self.duration}", Style("Times", 42, load_font=0, fill=bw(1)), t.inset(10)) if self.show_frame else None
             ])
         return res
     
     def package(self, filepath, output_folder):
         pass
 
+    def fn_to_frame(self, fn_name):
+        return 0
+
     def contactsheet(self, gx, sl=slice(0, None, None)):
         try:
             sliced = True
