@@ -3,7 +3,7 @@ import re
 from coldtype.pens.datpen import DATPen, DATPens
 from coldtype.text.composer import Graf, GrafStyle, Lockup
 from coldtype.text.reader import StyledString, Style
-from coldtype.color import hsl
+from drafting.color import hsl
 
 from pathlib import PurePath
 from typing import Optional, List, Callable, Tuple, Union
