@@ -1,6 +1,6 @@
 from coldtype import *
 
-obvs_ufo = DefconFont("assets/ColdtypeObviously_BlackItalic.ufo")
+obvs_ufo = raw_ufo("assets/ColdtypeObviously_BlackItalic.ufo")
 generic_txt = __sibling__("test_watch_scratch.txt")
 
 @renderable(watch=[obvs_ufo.path, generic_txt])
@@ -11,5 +11,4 @@ def test_watch_ufo_source(r):
             Style("assets/RecMono-CasualItalic.ttf", 50))
             .pens()
             .f(0.25)
-            .align(r.take(150, "mny"))),
-    ])
\ No newline at end of file
+            .align(r.take(150, "mny")))])
\ No newline at end of file
